Module text

Module text 

Structs

AddText
Declarative request to materialize a text entity using the active UI theme.
FontFaceEntry
FontRegistry
FontResource
LocalizedArg
LocalizedText
LocalizedTextFormat
TextPlugin
Materializes AddText components and keeps localized text in sync.
TypographyStyle

Enums

FontFamilyRole
TypographyFontStyle
TypographyTextTransform

Functions

apply_text_transform
control_typography
set_localized_text
Replaces the text content with a localized string resolved from key.
set_localized_text_format
Replaces the text content with a localized format string.
set_plain_text
Replaces the text content with plain text and clears localization bindings.
typography_from_patch