Structs
- AddText
- Declarative request to materialize a text entity using the active UI theme.
- Font
Face Entry - Font
Registry - Font
Resource - Localized
Arg - Localized
Text - Localized
Text Format - Text
Plugin - Materializes
AddTextcomponents and keeps localized text in sync. - Typography
Style
Enums
Functions
- apply_
text_ transform - control_
typography - set_
localized_ text - Replaces the text content with a localized string resolved from
key. - set_
localized_ text_ format - Replaces the text content with a localized format string.
- set_
plain_ text - Replaces the text content with plain text and clears localization bindings.
- typography_
from_ patch